@@ -76,7 +76,7 @@ void ParseData::writeReference( InputLoc &loc, Definition *prod, char *data )
 	out << "(";
 	if ( user ) {
 		if ( ( lel == 0 || lel->type == KlangEl::Term ) && tokenIsClass )
-			out << "(Token*)";
+			out << "(" << Token() << "*)";
 		else if ( lel != 0 && lel->type == KlangEl::NonTerm && lel->typeDef != 0 && 
 				lel->typeDef->isClass )
 			out << "(" << Lel_() << lel->typeDef->data << "*)";
