@@ -1,5 +1,5 @@
 /*
- *  Copyright 2001-2005 Adrian Thurston <thurston@complang.org>
+ *  Copyright 2001-2005, 2009 Adrian Thurston <thurston@complang.org>
  */
 
 /*  This file is part of Kelbt.
@@ -59,6 +59,7 @@ bool branchPointInfo = false;
 bool addUniqueEmptyProductions = false;
 bool inhibitLineDirectives = false;
 istream *inStream = 0;
+ArgsVector includePaths;
 
 /* Print a summary of the options. */
 void usage()
@@ -80,7 +81,7 @@ void usage()
 void version()
 {
 	cout << "Kelbt version " VERSION << " " PUBDATE << endl <<
-			"Copyright (c) 2005-2008 by Adrian Thurston" << endl;
+			"Copyright (c) 2005-2009 by Adrian Thurston" << endl;
 }
 
 /* Scans a string looking for the file extension. If there is a file
@@ -210,7 +211,7 @@ void scan( const char *fileName, istream &input );
 /* Main, process args and call yyparse to start scanning input. */
 int main(int argc, const char **argv)
 {
-	ParamCheck pc("io:VdvHh?-:tl", argc, argv);
+	ParamCheck pc("I:io:VdvHh?-:tl", argc, argv);
 
 	while ( pc.check() ) {
 		switch ( pc.state ) {
@@ -267,6 +268,9 @@ int main(int argc, const char **argv)
 			case 'l':
 				inhibitLineDirectives = true;
 				break;
+			case 'I':
+				includePaths.append( pc.paramArg );
+				break;
 			}
 			break;
 
